Modules
Macros
- category
- The
category!macro can be used to statically lookup a category by name from the registry - category_
concat - The
category_concat!macro is a variant ofcategory!using a slightly different syntax, for use in thedeclare_groupanddeclare_rulemacros in the analyzer
Structs
- Category
- Metadata for a diagnostic category